@@ -60,6 +60,11 @@ def login(**kwargs):
     asyncio.run(Auth.login(**kwargs))
 
 
+def notebook_login(**kwargs):
+    """This function guides user to log-in via P.A.T. or via browser."""
+    Auth.login_notebook(**kwargs)
+
+
 def logout():
     """Logout."""
     asyncio.run(Auth.logout())
