@@ -43,6 +43,7 @@ from hubble.executor.hubapi import (
     load_config,
     load_secret,
 )
+from hubble.utils.api_utils import get_json_from_response
 
 
 class HubIO:
@@ -660,7 +661,7 @@ metas:
             except Exception as e:  # IO related errors
                 self.logger.error(
                     f'Please report this session_id: [yellow bold]{req_header["jinameta-session-id"]}[/] '
-                    'to https://github.com/jina-ai/jina/issues'
+                    'to https://github.com/jina-ai/jina-hubble-sdk/issues'
                 )
                 raise e
 
@@ -985,18 +986,19 @@ metas:
     def _prettyprint_list_usage(self, console, executors, base_path):
         from rich import box
         from rich.panel import Panel
-        from rich.table import Table
+        from rich.table import Column, Table
 
         param_str = Table(
-            title=f'[red]base_path: {base_path}[/red]',
+            Column(header="Executor", no_wrap=True),
+            Column(header="Tag", no_wrap=True),
+            Column(header="Relative path", no_wrap=True),
             box=box.SIMPLE,
+            title=f'Base path: {base_path}',
+            title_style='blue',
             show_lines=True,
+            min_width=30 + len(str(base_path)),
         )
 
-        param_str.add_column('Executor')
-        param_str.add_column('Tag')
-        param_str.add_column('Relative_path')
-
         for item in executors:
             name = item['name']
             relative_path = item['relative_path']
@@ -1085,7 +1087,7 @@ metas:
         req_header = get_request_header()
 
         resp = _send_request_with_retry(pull_url, json=payload, headers=req_header)
-        resp = resp.json()['data']
+        resp = get_json_from_response(resp)['data']
 
         images = resp['package'].get('containers', [])
         image_name = images[0] if images else None
@@ -1143,11 +1145,12 @@ metas:
         port = None
 
         headers = get_request_header()
-        json_response = requests.post(
+        response = requests.post(
             url=urljoin(hubble.utils.get_base_url(), 'sandbox.get'),
             json=payload,
             headers=headers,
-        ).json()
+        )
+        json_response = get_json_from_response(response)
         if json_response.get('code') == 200:
             host = json_response.get('data', {}).get('host', None)
             port = json_response.get('data', {}).get('port', None)
@@ -1160,11 +1163,12 @@ metas:
             f'[bold green]🚧 Deploying sandbox for [bold white]{name}[/bold white] since none exists...'
         ):
             try:
-                json_response = requests.post(
+                response = requests.post(
                     url=urljoin(hubble.utils.get_base_url(), 'sandbox.create'),
                     json=payload,
                     headers=headers,
-                ).json()
+                )
+                json_response = get_json_from_response(response)
 
                 data = json_response.get('data') or {}
                 host = data.get('host', None)
@@ -1175,7 +1179,7 @@ metas:
                 console.log('🎉 Deployment completed, using it.')
             except BaseException:
                 console.log(
-                    '🚨 Deployment failed. Please raise an issue: https://github.com/jina-ai/jina/issues/new'
+                    '🚨 Deployment failed. Please raise an issue: https://github.com/jina-ai/jina-hubble-sdk/issues/new'
                 )
                 raise
 
